timeintervaltools.compute_logical_not_of_intervals
==================================================

.. autofunction:: abjad.tools.timeintervaltools.compute_logical_not_of_intervals.compute_logical_not_of_intervals
   :noindex:
